package
Version:
v2.0.85+incompatible
Opens a new window with list of versions in this module.
Published: Feb 26, 2016
License: Apache-2.0, Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GetToken(uaaURL, opsManagerUsername, opsManagerPassword, clientID, clientSecret string) (token string, err error)
type Token struct {
AccessToken string `json:"access_token"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.